Class CreateObservabilityConfigurationRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateObservabilityConfigurationRequest.Builder,CreateObservabilityConfigurationRequest>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanhasTags()For responses, this returns true if the service returned a value for the Tags property.final StringA name for the observability configuration.static Class<? extends CreateObservabilityConfigurationRequest.Builder>tags()A list of metadata items that you can associate with your observability configuration resource.final StringtoString()Returns a string representation of this object.final TraceConfigurationThe configuration of the tracing feature within this observability configuration.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
observabilityConfigurationName
A name for the observability configuration. When you use it for the first time in an Amazon Web Services Region, App Runner creates revision number
1of this name. When you use the same name in subsequent calls, App Runner creates incremental revisions of the configuration.The name
DefaultConfigurationis reserved. You can't use it to create a new observability configuration, and you can't create a revision of it.When you want to use your own observability configuration for your App Runner service, create a configuration with a different name, and then provide it when you create or update your service.
- Returns:
- A name for the observability configuration. When you use it for the first time in an Amazon Web Services
Region, App Runner creates revision number
1of this name. When you use the same name in subsequent calls, App Runner creates incremental revisions of the configuration.The name
DefaultConfigurationis reserved. You can't use it to create a new observability configuration, and you can't create a revision of it.When you want to use your own observability configuration for your App Runner service, create a configuration with a different name, and then provide it when you create or update your service.
-
traceConfiguration
The configuration of the tracing feature within this observability configuration. If you don't specify it, App Runner doesn't enable tracing.
- Returns:
- The configuration of the tracing feature within this observability configuration. If you don't specify it, App Runner doesn't enable tracing.
-
hasTags
public final boolean hasTags()For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
tags
A list of metadata items that you can associate with your observability configuration resource. A tag is a key-value pair.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTags()method.- Returns:
- A list of metadata items that you can associate with your observability configuration resource. A tag is a key-value pair.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateObservabilityConfigurationRequest.Builder,CreateObservabilityConfigurationRequest> - Specified by:
toBuilderin classAppRunnerRequest
-
builder
-
serializableBuilderClass
public static Class<? extends CreateObservabilityConfigurationRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-