Class EncryptionConfiguration

java.lang.Object
software.amazon.awssdk.services.apprunner.model.EncryptionConfiguration
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<EncryptionConfiguration.Builder,EncryptionConfiguration>

@Generated("software.amazon.awssdk:codegen") public final class EncryptionConfiguration extends Object implements SdkPojo, Serializable, ToCopyableBuilder<EncryptionConfiguration.Builder,EncryptionConfiguration>

Describes a custom encryption key that App Runner uses to encrypt copies of the source repository and service logs.

See Also: