Class SourceCodeVersion
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SourceCodeVersion.Builder,SourceCodeVersion>
Identifies a version of code that App Runner refers to within a source code repository.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic SourceCodeVersion.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends SourceCodeVersion.Builder>final StringtoString()Returns a string representation of this object.final SourceCodeVersionTypetype()The type of version identifier.final StringThe type of version identifier.final Stringvalue()A source code version.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
type
The type of version identifier.
For a git-based repository, branches represent versions.
If the service returns an enum value that is not available in the current SDK version,
typewill returnSourceCodeVersionType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- The type of version identifier.
For a git-based repository, branches represent versions.
- See Also:
-
typeAsString
The type of version identifier.
For a git-based repository, branches represent versions.
If the service returns an enum value that is not available in the current SDK version,
typewill returnSourceCodeVersionType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- The type of version identifier.
For a git-based repository, branches represent versions.
- See Also:
-
value
A source code version.
For a git-based repository, a branch name maps to a specific version. App Runner uses the most recent commit to the branch.
- Returns:
- A source code version.
For a git-based repository, a branch name maps to a specific version. App Runner uses the most recent commit to the branch.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<SourceCodeVersion.Builder,SourceCodeVersion>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-